using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Collections;

namespace BYOJeopardy_net
{
    public partial class FormEdit : Form
    {
        public FormEdit()
        {
            InitializeComponent();
        }
        public void FillTreeView()
        {
            this.treeView1.Nodes.Clear();
            ArrayList Topics = FormMain.jeopardydata.topics;
            for (int t = 0; t < Topics.Count; t++)
            {
                JTopic topic = (JTopic)Topics[t];
                TreeNode topicNode = new TreeNode(topic.TopicName);
                topicNode.Tag = "topic";
                for (int v = 0; v < topic.Values.Count; v++)
                {
                    TreeNode valueNode = new TreeNode(topic.Values[v].ToString());
                    valueNode.Tag = "value";
                    TreeNode questionNode = new TreeNode();
                    questionNode.Tag = "question";
                    TreeNode answerNode = new TreeNode();
                    answerNode.Tag = "answer";
                    if (topic.Questions.Count > v)
                    {
                        questionNode.Text = topic.Questions[v].ToString();
                    }
                    if (topic.Answers.Count > v)
                    {
                        answerNode.Text = topic.Answers[v].ToString();
                    }
                    valueNode.Nodes.Add(questionNode);
                    valueNode.Nodes.Add(answerNode);
                    topicNode.Nodes.Add(valueNode);
                }
                this.treeView1.Nodes.Add(topicNode);
            }
            has_Daily();
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            if (FormMain.FileName == "")
            {
                btnSaveAs_Click(sender, e);
            }
            else
            {
                Save();
            }
        }
        private void btnSaveAs_Click(object sender, EventArgs e)
        {
            if (this.saveFileDialog1.ShowDialog() == DialogResult.OK)
            {
                FormMain.FileName = this.saveFileDialog1.FileName;
                Save();
            }
        }
        private void Save()
        {
            FormMain.jeopardydata.topics.Clear();
            for (int t = 0; t < this.treeView1.Nodes.Count; t++)
            {
                TreeNode topicNode = this.treeView1.Nodes[t];
                JTopic topic = new JTopic();
                topic.TopicName = topicNode.Text;
                for (int v = 0; v < topicNode.Nodes.Count; v++)
                {
                    TreeNode valueNode = topicNode.Nodes[v];
                    topic.Values.Add(valueNode.Text);
                    topic.Questions.Add(valueNode.Nodes[0].Text);
                    topic.Answers.Add(valueNode.Nodes[1].Text);
                }
                FormMain.jeopardydata.topics.Add(topic);
            }
            FormMain.jeopardydata.SaveJeopardy(FormMain.FileName);
        }

        private void btnEditLabel_Click(object sender, EventArgs e)
        {
            this.treeView1.Focus();
            if ((string)this.treeView1.SelectedNode.Tag == "question" | (string)this.treeView1.SelectedNode.Tag == "answer")
            {
                rtfhtmlEditor.FormEdit frmeditques = new rtfhtmlEditor.FormEdit();
                frmeditques.htmlRichTextBox1.AddHTML(this.treeView1.SelectedNode.Text);
                if (frmeditques.ShowDialog() == DialogResult.OK)
                {
                    this.treeView1.SelectedNode.Text = frmeditques.htmlRichTextBox1.GetHTML(true, false);
                }
            }
            else
            {
                if (this.treeView1.SelectedNode.Text.ToLower() != "daily double")
                {
                    this.treeView1.SelectedNode.BeginEdit();
                }
            }
        }

        private void btnAddTopic_Click(object sender, EventArgs e)
        {
            TreeNode topicNode = new TreeNode("New Topic");
            topicNode.Tag = "topic";
            this.treeView1.Nodes.Add(topicNode);
            this.treeView1.SelectedNode = topicNode;
            topicNode.BeginEdit();
        }

        private void btnAddValue_Click(object sender, EventArgs e)
        {
            //Get parent Topic
            this.treeView1.Focus();
            TreeNode topicNode;
            if ((string)this.treeView1.SelectedNode.Tag == "topic")
            {
                topicNode = this.treeView1.SelectedNode;
            }
            else if ((string)this.treeView1.SelectedNode.Tag == "value")
            {
                topicNode = this.treeView1.SelectedNode.Parent;
            }
            else  //question or answer node
            {
                topicNode = this.treeView1.SelectedNode.Parent.Parent;
            }

            if (topicNode.Text.ToLower() == "daily double" && topicNode.Nodes.Count > 0)
            {
                return;
            }
               //Add Value Node
                TreeNode valueNode = new TreeNode("New Value");
                valueNode.Tag = "value";
                TreeNode questionNode = new TreeNode("New Question");
                questionNode.Tag = "question";
                TreeNode answerNode = new TreeNode("New Answer");
                answerNode.Tag = "answer";
                valueNode.Nodes.Add(questionNode);
                valueNode.Nodes.Add(answerNode);
                topicNode.Nodes.Add(valueNode);
                topicNode.Expand();
                valueNode.Expand();
                this.treeView1.SelectedNode = valueNode;
                valueNode.BeginEdit();
        }

        private void btnDelete_Click(object sender, EventArgs e)
        {
            this.treeView1.SelectedNode.EndEdit(false);
            if ((string)this.treeView1.SelectedNode.Tag == "topic" | (string)this.treeView1.SelectedNode.Tag == "value")
            {
                if ((string)this.treeView1.SelectedNode.Tag == "value" && (string)this.treeView1.SelectedNode.Parent.Text.ToLower() == "daily double")
                {
                    //If Daily double value
                    this.treeView1.SelectedNode.Parent.Remove();
                }
                else
                {
                    this.treeView1.SelectedNode.Remove();
                }
            }
            has_Daily();
        }

        private void btnAddDaily_Click(object sender, EventArgs e)
        {
            if (!has_Daily())
            {
                TreeNode topicNode = new TreeNode("Daily Double");
                topicNode.Tag = "topic";
                this.treeView1.Nodes.Add(topicNode);

                //Add Value Node
                TreeNode valueNode = new TreeNode("New Topic");
                valueNode.Tag = "value";
                TreeNode questionNode = new TreeNode("New Question");
                questionNode.Tag = "question";
                TreeNode answerNode = new TreeNode("New Answer");
                answerNode.Tag = "answer";
                valueNode.Nodes.Add(questionNode);
                valueNode.Nodes.Add(answerNode);
                topicNode.Nodes.Add(valueNode);
                topicNode.Expand();
                valueNode.Expand();
                this.treeView1.SelectedNode = valueNode;
                valueNode.BeginEdit();
                this.btnAddDaily.Enabled = false;
            }
        }

        private bool has_Daily()
        {
            for (int t = 0; t < this.treeView1.Nodes.Count; t++)
            {
                if (this.treeView1.Nodes[t].Text.ToLower() == "daily double" && this.treeView1.Nodes[t].Nodes.Count > 0)
                {
                    this.btnAddDaily.Enabled = false;
                    return true;
                }
            }
            this.btnAddDaily.Enabled = true;
            return false;
        }
    }
}